# remirepo spec file for php-pecl-pam
#
# Copyright (c) 2021-2023 Remi Collet
# License: CC-BY-SA-4.0
# https://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

%{?scl:%scl_package php-pecl-pam}

%global pecl_name pam
%global with_zts  0%{!?_without_zts:%{?__ztsphp:1}}
# after 40-raphf
%global ini_name  50-%{pecl_name}.ini

%global upstream_version 2.2.5
#global upstream_prever  beta1
#global upstream_lower   beta1
%global sources          %{pecl_name}-%{upstream_version}%{?upstream_prever}
%global _configure       ../%{sources}/configure

Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Summary:        PAM integration
Version:        %{upstream_version}%{?upstream_prever:~%{upstream_lower}}
Release:        1%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:        PHP-3.01
URL:            https://pecl.php.net/package/PAM

Source0:        https://pecl.php.net/get/%{sources}.tgz

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-devel >= 7.3
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  pam-devel

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}

Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}

%if "%{?packager}" == "Remi Collet" && 0%{!?scl:1} && 0%{?rhel}
# Other third party repo stuff
%if "%{php_version}" > "7.4"
Obsoletes:     php74-pecl-%{pecl_name}  <= %{version}
%endif
%if "%{php_version}" > "8.0"
Obsoletes:     php80-pecl-%{pecl_name}  <= %{version}
%endif
%if "%{php_version}" > "8.1"
Obsoletes:     php81-pecl-%{pecl_name}  <= %{version}
%endif
%endif


%description
This extension provides PAM (Pluggable Authentication Modules) integration.
PAM is a system of libraries that handle the authentication tasks of
applications and services. The library provides a stable API for applications
to defer to for authentication tasks.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -c -q 

%{?_licensedir:sed -e '/LICENSE/s/role="doc"/role="src"/' -i package.xml}

cd %{sources}
extver=$(sed -n '/#define PHP_PAM_VERSION/{s/.* "//;s/".*$//;p}' php_pam.h)
if test "x${extver}" != "x%{upstream_version}%{?upstream_prever}%{?gh_date:dev}"; then
   : Error: Upstream version is now ${extver}, expecting %{upstream_version}%{?upstream_prever}%{?gh_date:dev}.
   : Update the pdover macro and rebuild.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so

; Configuration
;pam.servicename = 'php'
;pam.force_servicename = Off
EOF


%build
%{?dtsenable}
gcc --version

peclconf() {
%configure \
  --with-pam \
  --with-libdir=%{_lib} \
  --with-php-config=$1
}
cd %{sources}
%{__phpize}

cd ../NTS
peclconf %{__phpconfig}
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
peclconf %{__ztsphpconfig}
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# Install XML package description
install -Dpm 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

# install config file
install -Dpm644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}
install -Dpm644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
cd %{sources}
for i in $(grep 'role="doc"' ../package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 $i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'
%endif


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%files
%{?_licensedir:%license %{sources}/LICENSE}
%doc %{pecl_docdir}/%{pecl_name}
%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so
%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif

%changelog
* Mon Sep 25 2023 Remi Collet <remi@remirepo.net> - 2.2.5-1
- update to 2.2.5

* Fri Sep  1 2023 Remi Collet <remi@remirepo.net> - 2.2.4-2
- build out of sources tree

* Wed Jan 19 2022 Remi Collet <remi@remirepo.net> - 2.2.4-1
- update to 2.2.4

* Wed Sep 01 2021 Remi Collet <remi@remirepo.net> - 2.2.3-2
- rebuild for 8.1.0RC1

* Tue Jun  8 2021 Remi Collet <remi@remirepo.net> - 2.2.3-1
- update to 2.2.3 (no change)
- raise dependency on PHP 7.3

* Tue Jun  8 2021 Remi Collet <remi@remirepo.net> - 2.2.2-1
- update to 2.2.2
- drop patch merged upstream

* Mon Jun  7 2021 Remi Collet <remi@remirepo.net> - 2.2.1-1
- new package
- add patch for ZTS build from
  https://github.com/amishmm/php-pam/pull/4
